package shop

import (
	"database/sql"
	"fmt"
	"server/console"
	mysqlmgr "server/db/mysql"
	"server/msg"
	"server/user"
	"time"

	"github.com/name5566/leaf/gate"
)

func init() {
	console.Log("注册BuyShopItem")
}

func OnBuy(args []interface{}) {
	m := args[0].(*msg.BuyShopItem)
	console.Log("玩家购买了商品id为：", m.Id)
	a := args[1].(gate.Agent)
	user_id := a.UserData().(*msg.UserInfo).UserId
	user.AddUserCoin(100, user_id)
}

type ShopItem struct {
	ID         int       `db:"id"`
	ShopType   int       `db:"shop_type"`
	Name       string    `db:"name"`
	Price      int       `db:"price"`
	Num        int       `db:"num"`
	CreateTime time.Time `db:"create_time"` // 添加了create_time字段
}

func GetShopList(shop_type int) ([]*msg.ShopItem, error) {
	rows, err := mysqlmgr.Query("SELECT * FROM shop_config WHERE shop_type = ? LIMIT 100 ", shop_type)
	if err != nil {
		return nil, fmt.Errorf("query failed: %v", err)
	}
	defer rows.Close()

	var results []*msg.ShopItem
	var nullTime sql.NullTime // 用于处理可能的NULL时间值
	for rows.Next() {
		var shop_item ShopItem
		if err := rows.Scan(&shop_item.ID,
			&shop_item.ShopType,
			&shop_item.Name,
			&shop_item.Price,
			&shop_item.Num,
			&nullTime); err != nil {
			return nil, fmt.Errorf("failed to scan row: %v", err)
		}
		results = append(results, &msg.ShopItem{
			Id:    fmt.Sprint(shop_item.ID),
			Name:  shop_item.Name,
			Price: int32(shop_item.Price),
			Num:   int32(shop_item.Num),
		})
	}

	if err := rows.Err(); err != nil {
		return nil, fmt.Errorf("rows error: %v", err)
	}

	return results, nil
}
